==> adeptarch_base-9.0.1%2B1.tar.gz: lib/src/filters/number_filter.dart <==
import 'package:adeptarch_base/src/filters/filter.dart';
import 'package:json_annotation/json_annotation.dart';

part 'number_filter.g.dart';

const int NUMBER_FILTER_ALL = 0,
    NUMBER_FILTER_EQUALS = 1,
    NUMBER_FILTER_GREATER_THAN = 2,
    NUMBER_FILTER_GREATER_OR_EQUAL_THAN = 3,
    NUMBER_FILTER_LESS_THAN = 4,
    NUMBER_FILTER_LESS_OR_EQUAL_THAN = 5,
    NUMBER_FILTER_RANGE = 6;

@JsonSerializable()
class NumberFilter extends Filter<NumberFilter, num> {
  int numberFilterType;
  num? valueMin;
  num? valueMax;
  NumberFilter({
    required String? param,
    SortMode? sortMode,
    FilterActionType? filterActionType,
    this.numberFilterType = NUMBER_FILTER_ALL,
  }) : super(
          param: param,
          sortMode: sortMode,
          filterActionType: filterActionType,
        );

  @override
  void reset() {
    valueMin = null;
    valueMax = null;
    numberFilterType = NUMBER_FILTER_ALL;
    super.reset();
  }

  @override
  bool get isReady {
    if (!isValid) return false;
    return true;
  }

  @override
  bool get isValid {
    if (param == null) return false;
    if (numberFilterType == NUMBER_FILTER_RANGE) {
      if (valueMin == null || valueMax == null) {
        return false;
      } else if (valueMin! > valueMax!) {
        return false;
      }
    }
    return true;
  }

  Map<String, dynamic> buildNumberFilter() {
    switch (numberFilterType) {
      case NUMBER_FILTER_EQUALS:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.EQUALS,
            value: valueMin));
        break;
      case NUMBER_FILTER_GREATER_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.GREATER_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_GREATER_OR_EQUAL_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.GREATER_OR_EQUAL_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_LESS_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.LESS_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_LESS_OR_EQUAL_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.LESS_OR_EQUAL_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_RANGE:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.GREATER_OR_EQUAL_THAN,
            value: valueMin));
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.LESS_OR_EQUAL_THAN,
            value: valueMax));
        break;
    }

    return filtersBuilder.build();
  }

  @override
  Map<String, dynamic> build() {
    super.build();
    return buildNumberFilter();
  }

  @override
  Map<String, dynamic> toJson() => _$NumberFilterToJson(this);
  @override
  NumberFilter? fromJsonMap(Map<String, dynamic>? json) =>
      json != null ? NumberFilter.fromJson(json) : null;
  factory NumberFilter.fromJson(Map<String, dynamic> json) =>
      _$NumberFilterFromJson(json);
}

==> adeptarch_base-12.0.0%2B1.tar.gz: lib/src/filters/number_filter.dart <==
import 'package:adeptarch_base/src/filters/filter.dart';
import 'package:json_annotation/json_annotation.dart';

part 'number_filter.g.dart';

const int NUMBER_FILTER_ALL = 0,
    NUMBER_FILTER_EQUALS = 1,
    NUMBER_FILTER_GREATER_THAN = 2,
    NUMBER_FILTER_GREATER_OR_EQUAL_THAN = 3,
    NUMBER_FILTER_LESS_THAN = 4,
    NUMBER_FILTER_LESS_OR_EQUAL_THAN = 5,
    NUMBER_FILTER_RANGE = 6;

@JsonSerializable()
class NumberFilter extends Filter<NumberFilter, num> {
  int numberFilterType;
  num? valueMin;
  num? valueMax;
  NumberFilter({
    required super.param,
    super.sortMode,
    super.filterActionType,
    this.numberFilterType = NUMBER_FILTER_ALL,
  });

  @override
  void reset() {
    valueMin = null;
    valueMax = null;
    numberFilterType = NUMBER_FILTER_ALL;
    super.reset();
  }

  @override
  bool get isReady {
    if (!isValid) return false;
    return true;
  }

  @override
  bool get isValid {
    if (param == null) return false;
    if (numberFilterType == NUMBER_FILTER_RANGE) {
      if (valueMin == null || valueMax == null) {
        return false;
      } else if (valueMin! > valueMax!) {
        return false;
      }
    }
    return true;
  }

  Map<String, dynamic> buildNumberFilter() {
    switch (numberFilterType) {
      case NUMBER_FILTER_EQUALS:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.EQUALS,
            value: valueMin));
        break;
      case NUMBER_FILTER_GREATER_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.GREATER_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_GREATER_OR_EQUAL_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.GREATER_OR_EQUAL_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_LESS_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.LESS_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_LESS_OR_EQUAL_THAN:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.LESS_OR_EQUAL_THAN,
            value: valueMin));
        break;
      case NUMBER_FILTER_RANGE:
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.GREATER_OR_EQUAL_THAN,
            value: valueMin));
        filtersBuilder.putAll(FilterActions.build(
            param: param!,
            filterActionType: filterActionType,
            action: FilterActions.LESS_OR_EQUAL_THAN,
            value: valueMax));
        break;
    }

    return filtersBuilder.build();
  }

  @override
  Map<String, dynamic> build() {
    super.build();
    return buildNumberFilter();
  }

  @override
  Map<String, dynamic> toJson() => _$NumberFilterToJson(this);
  @override
  NumberFilter? fromJsonMap(Map<String, dynamic>? json) =>
      json != null ? NumberFilter.fromJson(json) : null;
  factory NumberFilter.fromJson(Map<String, dynamic> json) =>
      _$NumberFilterFromJson(json);
}
